@@ -3,7 +3,6 @@
 import argparse
 import os
 import sys
-import logging
 
 
 def parseOptions():
@@ -13,11 +12,11 @@ def parseOptions():
     basename = os.path.basename(sys.argv[0]).rstrip('.py')
     dirname  = os.path.dirname(__file__)
 
-    config_dir  = os.environ['HOME']+F'/.config/{basename}'
+    config_dir  = os.environ['HOME'] + F'/.config/{basename}'
     # config_file = os.environ['HOME']+F'/.config/{basename}.conf'
     config_file = F'/etc/contextualise_ssh_server.conf'
     config_file = F'contextualise_ssh_server.conf'
-    log_file    = folder_of_executable+F'/{basename}.log'
+    log_file    = folder_of_executable + F'/{basename}.log'
     log_file    = ""
 
     if not os.path.exists(config_dir):
@@ -26,7 +25,7 @@ def parseOptions():
     parser = argparse.ArgumentParser(formatter_class=argparse.ArgumentDefaultsHelpFormatter)
 
     parser.add_argument("--verbose",    "-v",   action="count", default=0, help="Verbosity")
-    parser.add_argument("--debug",      "-d",   action="count", default=0, help="Debug logging level")
+    parser.add_argument("--debug",      "-d",   action="count", default=0, help="Logmode debug")
     parser.add_argument('--config',     '-c',   default=config_file,
             help="config file")
     parser.add_argument('--basename',           default=basename)
@@ -34,8 +33,6 @@ def parseOptions():
     parser.add_argument('--logfile',            default=log_file, help='logfile')
     parser.add_argument('--loglevel',           default=os.environ.get("LOG", "WARNING").upper(),
                                                 help='Debugging Level')
-    
-
     parser.add_argument(dest="access_token",    default=None, nargs="+",
                                                 help="An access token (without 'Bearer ')",)
     return parser
